@@ -9,7 +9,7 @@ from errors import snserror
 
 import platform
 
-_dir_static_data = snsconf.SNSConf.SNSAPI_DIR_STATIC_DATA
+_dir_static_data = snsconf.SNSConf._SNSAPI_DIR_STATIC_DATA
 
-__versioninfo__ = (0, 6, 2)
+__versioninfo__ = (0, 6, 3)
 __version__ = '.'.join(map(str, __versioninfo__))
